@@ -31,6 +31,7 @@ from dstk.pytorch._utils import check_tensor, is_dist_avail_and_initialized
 from dstk.pytorch._callback import (CallbackInterface, CallbackHandler,
                                     FitState, FitControl, PrintCallback,
                                     ProgressBarCallback, EarlyStoppingCallback)
+from dstk.pytorch._utils_distrib import is_main_process
 from dstk.utils.errors import DivergenceError
 
 
@@ -474,7 +475,6 @@ class BaseEnvironnement(BaseEstimator):
         -------
         loss : Valeur de la fonction coût au travers du mini-batch.
         """
-        self.eval()
         if control.device.type != "cpu":
             for key, value in data.items():
                 if key not in control.expected_key_to_device:
@@ -483,6 +483,7 @@ class BaseEnvironnement(BaseEstimator):
                     else:
                         data[key] = value.to(control.device)
         with torch.no_grad():
+            self.eval()
             output = self.forward(**data)
             if control.target_checktensor:
                 target = check_tensor(data[control.target_field])
@@ -583,6 +584,7 @@ class BaseEnvironnement(BaseEstimator):
         optimizer_kargs: Dict[str, any]=dict(),
         nb_epoch: int,
         iter_eval: Optional[int]=None,
+        eval_in_main_process: bool=True,
         callbacks: Optional[List[CallbackInterface]]=None,
         device: str='cuda:0',
         mixed_type_gpu: bool=False,
@@ -649,6 +651,9 @@ class BaseEnvironnement(BaseEstimator):
             défaut) les évaluations du modèle seront à la fin des époques. 
             Si un entier positif est renseigné les évaluations auront lieu 
             tous les iter_eval itérations d'apprentissage.
+        eval_in_main_process: bool (=True)
+            Exécute la phase d'évaluation dans le process principal dans le
+            cadre multi-GPU/multi-node.
         callbacks : Optional[List[CallbackInterface]]
             Liste de callback intervenant aux différentes étapes de 
             l'entraînement et de l'évaluation. Pour avoir la liste des 
@@ -755,14 +760,32 @@ class BaseEnvironnement(BaseEstimator):
             )
 
         if (
-                gradient_accumulation is not None and
-                iter_eval < gradient_accumulation
+            gradient_accumulation is not None and
+            iter_eval < gradient_accumulation
         ):
             warn(
                 "iter_eval < gradient_accumulation donc à chaque itération "
                 "un pas de gradient ne sera pas effectué."
             )
 
+        # marqueur permettant d'éxécuter la partir éval dans le processus
+        # principale ou partout (pour le cas multi-GPU/Node
+        if eval_in_main_process:
+            test_eval_prosses = is_main_process
+        else:
+            test_eval_prosses = lambda: True
+
+        if not (
+            eval_in_main_process
+            or eval_dataset is None
+            or hasattr(eval_dataset.sampler, 'set_epoch')
+        ):
+            raise AttributeError(
+                "Vous souhaitez réaliser l'éxécution du dataset en parallèle "
+                "mais il semblerait que le dataset ne soit pas compatible "
+                "pour la parallélisation (voir multi-GPU/multi-Note)."
+            )
+
         # Permet de construire le modèle avec les paramètres actuels du fit.
         if build:
             self.build()
@@ -881,7 +904,10 @@ class BaseEnvironnement(BaseEstimator):
             for n_epoch in range(nb_epoch):
                 if is_dist_avail_and_initialized():
                     dataset.sampler.set_epoch(n_epoch)
-                    if eval_dataset:
+                    if (
+                        eval_dataset
+                        and hasattr(eval_dataset.sampler, 'set_epoch')
+                    ):
                         eval_dataset.sampler.set_epoch(n_epoch)
                     torch.distributed.barrier()
                 state.n_epoch = n_epoch
@@ -895,19 +921,20 @@ class BaseEnvironnement(BaseEstimator):
                 )
                 for ii, batch in enumerate(dataset):
                     if (
-                        eval_dataset and
-                        self._mod(state.n_iter, iter_eval) == 0
+                        eval_dataset
+                        and self._mod(state.n_iter, iter_eval) == 0
                     ):
-                        self._iter_eval(
-                            eval_dataset=eval_dataset,
-                            loss_fn=loss_fn,
-                            loss_kargs=loss_kargs,
-                            state=state,
-                            control=control,
-                            list_callbacks=list_callbacks
-                        )
-                        if control.diverge or control.training_stop:
-                            break
+                        if test_eval_prosses():
+                            self._iter_eval(
+                                eval_dataset=eval_dataset,
+                                loss_fn=loss_fn,
+                                loss_kargs=loss_kargs,
+                                state=state,
+                                control=control,
+                                list_callbacks=list_callbacks
+                            )
+                            if control.diverge or control.training_stop:
+                                break
                         if is_dist_avail_and_initialized():
                             torch.distributed.barrier()
                     try:
