@@ -1194,7 +1194,7 @@ class ProgressBarCallback(CallbackInterface, metaclass=SuperclassDocstring):
     def __post_init__(self):
         from dstk.pytorch._utils_distrib import is_main_process
         if 'LOCAL_RANK' in os.environ:
-            self.is_main = lambda: os.environ['LOCAL_RANK'] == 0
+            self.is_main = lambda: int(os.environ['LOCAL_RANK']) == 0
         else:
             self.is_main = is_main_process
 
